==> 2.0.4.tar.gz: ios/Classes/Models/NativeToFlutter/FireworkEventName.swift <==
//
//  FireworkEventName.swift
//  fw_flutter_sdk
//
//  Created by Jeff Zheng on 2021/12/21.
//

import Foundation

/// Video event
enum FWEventName: String, CaseIterable {
    case sdkInit = "fw:sdk-init"
    case customCTAClick = "fw:custom-cta-click"
    case videoPlayback = "fw:video-playback"
    case videoFeedClick = "fw:video-feed-click"
    case nativeAppLanguageUpdated = "fw:native-app-language-updated"
}

enum VideoPlaybackSubEventName: String {
    case impression = "fw:video:impression"
    case start = "fw:video:start"
    case pause = "fw:video:pause"
    case resume = "fw:video:resume"
    case firstQuartile = "fw:video:first-quartile"
    case midpoint = "fw:video:midpoint"
    case thirdQuartile = "fw:video:third-quartile"
    case complete = "fw:video:complete"
    case adStart = "fw:video:ad-start"
    case adEnd = "fw:video:ad-end"
    case clickCTA = "fw:video:click-cta"
    case clickShare = "fw:video:click-share"
}

/// Shopping event
enum ShoppingEventName: String, CaseIterable {
    case updateProductDetails = "fw:shopping:update-product-details"
    case ctaButtonClick = "fw:shopping:cta-button-click"
    case clickCartIcon = "fw:shopping:click-cart-icon"
    case customLinkButtonClick = "fw:shopping:custom-link-button-click"
}

/// Live stream event
enum LiveStreamEventName: String, CaseIterable {
    case livestream = "fw:livestream"
    case livestreamChat = "fw:livestream-chat"
}

enum LiveStreamSubEventName: String {
    case userDidjoin = "fw:livestream:user-join"
    case userDidLeave = "fw:livestream:user-leave"
    case userSendLike = "fw:livestream:user-send-like"
}

enum LiveStreamChatSubEventName: String {
    case userSendChat = "fw:livestream:user-send-chat"
}

enum VideoFeedEventName: String {
    case onVideoFeedLoadFinished
}

enum StoryBlockEventName: String {
    case onStoryBlockLoadFinished
}

==> 2.4.6.tar.gz: ios/Classes/Models/NativeToFlutter/FireworkEventName.swift <==
//
//  FireworkEventName.swift
//  fw_flutter_sdk
//
//  Created by Jeff Zheng on 2021/12/21.
//

import Foundation

/// Video event
enum FWEventName: String, CaseIterable {
    case sdkInit = "fw:sdk-init"
    case customCTAClick = "fw:custom-cta-click"
    case videoPlayback = "fw:video-playback"
    case videoFeedClick = "fw:video-feed-click"
    case nativeAppLanguageUpdated = "fw:native-app-language-updated"
}

enum VideoPlaybackSubEventName: String {
    case impression = "fw:video:impression"
    case start = "fw:video:start"
    case pause = "fw:video:pause"
    case resume = "fw:video:resume"
    case firstQuartile = "fw:video:first-quartile"
    case midpoint = "fw:video:midpoint"
    case thirdQuartile = "fw:video:third-quartile"
    case complete = "fw:video:complete"
    case adStart = "fw:video:ad-start"
    case adEnd = "fw:video:ad-end"
    case clickCTA = "fw:video:click-cta"
    case clickShare = "fw:video:click-share"
}

/// Shopping event
enum ShoppingEventName: String, CaseIterable {
    case updateProductDetails = "fw:shopping:update-product-details"
    case ctaButtonClick = "fw:shopping:cta-button-click"
    case clickCartIcon = "fw:shopping:click-cart-icon"
    case customLinkButtonClick = "fw:shopping:custom-link-button-click"
    case customProductCardTap = "fw:shopping:custom-product-card-tap"
}

/// Live stream event
enum LiveStreamEventName: String, CaseIterable {
    case livestream = "fw:livestream"
    case livestreamChat = "fw:livestream-chat"
}

enum LiveStreamSubEventName: String {
    case userDidjoin = "fw:livestream:user-join"
    case userDidLeave = "fw:livestream:user-leave"
    case userSendLike = "fw:livestream:user-send-like"
}

enum LiveStreamChatSubEventName: String {
    case userSendChat = "fw:livestream:user-send-chat"
}

enum VideoFeedEventName: String {
    case onVideoFeedLoadFinished
}

enum StoryBlockEventName: String {
    case onStoryBlockLoadFinished, onStoryBlockPdpVisibilityChange
}

enum VideoFeedPictureInPictureEventName: String {
    case onVideoFeedDidStartPictureInPicture, onVideoFeedDidStopPictureInPicture
}

enum StoryBlockPictureInPictureEventName: String {
    case onStoryBlockDidStartPictureInPicture, onStoryBlockDidStopPictureInPicture
}
